The Capital License Article 1. Any works that use this license must attempt to avoid ambiguous all caps writting. It's tough to read in braille and speech to text might not easily know if it's an acronym or not. As well, it is very unpleasant. Please maintain a calm, tropical tonality to your voice, spoken or otherwise. If you enjoy reading capital letters, please consider using a font that displays lower case letters as shorter equivalents of their upper case counterparts. Article 2. This "module" and the "license" collectively may be best metaphorically understood as a region of a homo-sapien skull. Please treat it with exactly the same as you would an actual living homo-sapien skull that you have been giving non-exclusive license to bioengineer from genetic schematics. That is the blessing of the author. However, if this work links to or includes "modules" that have restrictions not listed in this license, please respect those restrictions. In summation, modification, additions, subtractions, inclusions, and exclusions, are at your discretion unless otherwise restricted by included or linked modules.